@@ -1,19 +1,18 @@
 #! /usr/bin/perl
 
-# $Id: uvt-email-template.pl 39332 2013-05-03 07:57:53Z wsl $
+# $Id: uvt-email-template.pl 39337 2013-05-03 09:42:34Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/uvt-email-template/bin/uvt-email-template.pl $
 
 use strict;
 use warnings FATAL => 'all';
 use utf8;
 
+our $PACKAGE;
 our $pkgdatadir //= our $datadir ? "$datadir/$PACKAGE" : 'share';
 
-BEGIN { unshift @INC, qw(lib) }
-
 use UvT::Email::Template;
 
-my $e = new UvT::Email::Template(htmltemplate => "$pkgdatadir/html.xsl");
+my $e = new UvT::Email::Template(htmltemplate => "$pkgdatadir/html.xsl", imagepath => $pkgdatadir);
 
 print $e->format($ARGV[0], Subject => 'testje');
 
